Index: test/mjsunit/compiler/parallel-proto-change.js |
diff --git a/test/mjsunit/compiler/parallel-proto-change.js b/test/mjsunit/compiler/parallel-proto-change.js |
index 25ea3b59dfc5b83b6d7e80f697fc8ba22d3f5c08..76022798934329461b86779beda093394b3bd9d9 100644 |
--- a/test/mjsunit/compiler/parallel-proto-change.js |
+++ b/test/mjsunit/compiler/parallel-proto-change.js |
@@ -26,10 +26,10 @@ |
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
// Flags: --allow-natives-syntax |
-// Flags: --parallel-recompilation --parallel-recompilation-delay=50 |
+// Flags: --concurrent-recompilation --concurrent-recompilation-delay=50 |
-if (!%IsParallelRecompilationSupported()) { |
- print("Parallel recompilation is disabled. Skipping this test."); |
+if (!%IsConcurrentRecompilationSupported()) { |
+ print("Concurrent recompilation is disabled. Skipping this test."); |
quit(); |
} |
@@ -41,11 +41,11 @@ o.__proto__ = { __proto__: { bar: function() { return 1; } } }; |
assertEquals(1, f(o)); |
assertEquals(1, f(o)); |
// Mark for parallel optimization. |
%OptimizeFunctionOnNextCall(f, "parallel"); |
// Trigger optimization in the parallel thread. |
assertEquals(1, f(o)); |
// While parallel recompilation is running, optimization not yet done. |
assertUnoptimized(f, "no sync"); |
// Change the prototype chain during optimization to trigger map invalidation. |
o.__proto__.__proto__ = { bar: function() { return 2; } }; |
@@ -41,11 +41,11 @@ o.__proto__ = { __proto__: { bar: function() { return 1; } } }; |
assertEquals(1, f(o)); |
assertEquals(1, f(o)); |
-// Mark for parallel optimization. |
-%OptimizeFunctionOnNextCall(f, "parallel"); |
-// Trigger optimization in the parallel thread. |
+// Mark for concurrent optimization. |
+%OptimizeFunctionOnNextCall(f, "concurrent"); |
+// Trigger optimization in the background thread. |
assertEquals(1, f(o)); |
@@ -41,11 +41,11 @@ o.__proto__ = { __proto__: { bar: function() { return 1; } } }; |
assertEquals(1, f(o)); |
-// While parallel recompilation is running, optimization not yet done. |
+// While concurrent recompilation is running, optimization not yet done. |
assertUnoptimized(f, "no sync"); |
// Change the prototype chain during optimization to trigger map invalidation. |